summaryrefslogtreecommitdiff
path: root/src/ai/ai_core.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/ai/ai_core.cpp')
-rw-r--r--src/ai/ai_core.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/ai/ai_core.cpp b/src/ai/ai_core.cpp
index f2bfc4292..1c7005b74 100644
--- a/src/ai/ai_core.cpp
+++ b/src/ai/ai_core.cpp
@@ -289,9 +289,9 @@ void CcAI(const CommandCost &result, TileIndex tile, uint32 p1, uint32 p2)
return DAYS_IN_YEAR;
}
/* static */ char *AI::GetConsoleList(char *p, const char *last)
{
- return AI::ai_scanner->GetAIConsoleList(p, last);
+ return AI::ai_scanner->GetAIConsoleList(p, last, newest_only);
}
/* static */ char *AI::GetConsoleLibraryList(char *p, const char *last)
@@ -289,9 +289,9 @@ void CcAI(const CommandCost &result, TileIndex tile, uint32 p1, uint32 p2)
return DAYS_IN_YEAR;
}
-/* static */ char *AI::GetConsoleList(char *p, const char *last)
+/* static */ char *AI::GetConsoleList(char *p, const char *last, bool newest_only)
{